@@ -37,6 +37,9 @@ G_BEGIN_DECLS
 #define G_VFS_DBUS_MOUNT_OP_MOUNT_MOUNTABLE "MountMountable"
 #define G_VFS_DBUS_MOUNT_OP_UNMOUNT_MOUNTABLE "UnountMountable"
 #define G_VFS_DBUS_MOUNT_OP_EJECT_MOUNTABLE "EjectMountable"
+#define G_VFS_DBUS_MOUNT_OP_START_MOUNTABLE "StartMountable"
+#define G_VFS_DBUS_MOUNT_OP_STOP_MOUNTABLE "StopMountable"
+#define G_VFS_DBUS_MOUNT_OP_POLL_MOUNTABLE "PollMountable"
 #define G_VFS_DBUS_MOUNT_OP_SET_DISPLAY_NAME "SetDisplayName"
 #define G_VFS_DBUS_MOUNT_OP_DELETE "Delete"
 #define G_VFS_DBUS_MOUNT_OP_TRASH "Trash"
@@ -73,6 +76,8 @@ G_BEGIN_DECLS
 #define G_VFS_DBUS_MOUNT_OPERATION_INTERFACE "org.gtk.vfs.MountOperation"
 #define G_VFS_DBUS_MOUNT_OPERATION_OP_ASK_PASSWORD "askPassword"
 #define G_VFS_DBUS_MOUNT_OPERATION_OP_ASK_QUESTION "askQuestion"
+#define G_VFS_DBUS_MOUNT_OPERATION_OP_SHOW_PROCESSES "showProcesses"
+#define G_VFS_DBUS_MOUNT_OPERATION_OP_ABORTED "aborted"
 
 /* Implemented by the spawner of a process, the spawned process sends the
    spawned message (with noreply) when it has spawned and gotten a dbus id */
@@ -91,6 +96,15 @@ G_BEGIN_DECLS
 #define G_VFS_DBUS_MONITOR_CLIENT_INTERFACE "org.gtk.vfs.MonitorClient"
 #define G_VFS_DBUS_MONITOR_CLIENT_OP_CHANGED "Changed"
 
+/* The well known name of the metadata daemon */
+#define G_VFS_DBUS_METADATA_NAME "org.gtk.vfs.Metadata"
+#define G_VFS_DBUS_METADATA_PATH "/org/gtk/vfs/metadata"
+#define G_VFS_DBUS_METADATA_INTERFACE "org.gtk.vfs.Metadata"
+#define G_VFS_DBUS_METADATA_OP_SET "Set"
+#define G_VFS_DBUS_METADATA_OP_GET "Get"
+#define G_VFS_DBUS_METADATA_OP_UNSET "Unset"
+#define G_VFS_DBUS_METADATA_OP_REMOVE "Remove"
+#define G_VFS_DBUS_METADATA_OP_MOVE "Move"
 
 /* Mounts time out in 10 minutes, since they can be slow, with auth, etc */
 #define G_VFS_DBUS_MOUNT_TIMEOUT_MSECS (1000*60*10)
@@ -113,6 +127,7 @@ typedef struct {
 #define G_VFS_DAEMON_SOCKET_PROTOCOL_REQUEST_CANCEL 3
 #define G_VFS_DAEMON_SOCKET_PROTOCOL_REQUEST_SEEK_SET 4
 #define G_VFS_DAEMON_SOCKET_PROTOCOL_REQUEST_SEEK_END 5
+#define G_VFS_DAEMON_SOCKET_PROTOCOL_REQUEST_QUERY_INFO 6
 
 /*
 read, readahead reply:
@@ -123,6 +138,10 @@ type, pos (64),
 
 error:
 type, code, size, data (size bytes, 2 strings: domain, message)
+
+info:
+type,    0, size, data 
+
 */
 
 typedef struct {
@@ -139,11 +158,13 @@ typedef struct {
 #define G_VFS_DAEMON_SOCKET_PROTOCOL_REPLY_SEEK_POS 2
 #define G_VFS_DAEMON_SOCKET_PROTOCOL_REPLY_WRITTEN  3
 #define G_VFS_DAEMON_SOCKET_PROTOCOL_REPLY_CLOSED   4
+#define G_VFS_DAEMON_SOCKET_PROTOCOL_REPLY_INFO     5
 
 #define G_FILE_INFO_INNER_TYPE_AS_STRING         \
   DBUS_TYPE_ARRAY_AS_STRING			 \
     DBUS_STRUCT_BEGIN_CHAR_AS_STRING		 \
       DBUS_TYPE_STRING_AS_STRING		 \
+      DBUS_TYPE_UINT32_AS_STRING		 \
       DBUS_TYPE_VARIANT_AS_STRING		 \
     DBUS_STRUCT_END_CHAR_AS_STRING
 
@@ -167,12 +188,14 @@ gpointer   _g_dbus_attribute_as_pointer          (GFileAttributeType          ty
 const char*_g_dbus_type_from_file_attribute_type (GFileAttributeType          type);
 void       _g_dbus_append_file_attribute         (DBusMessageIter            *iter,
 						  const char                 *attribute,
+						  GFileAttributeStatus        status,
 						  GFileAttributeType          type,
 						  gpointer                    value_p);
 void       _g_dbus_append_file_info              (DBusMessageIter            *iter,
 						  GFileInfo                  *file_info);
 gboolean   _g_dbus_get_file_attribute            (DBusMessageIter            *iter,
 						  gchar                     **attribute,
+						  GFileAttributeStatus       *status,
 						  GFileAttributeType         *type,
 						  GDbusAttributeValue        *value);
 GFileInfo *_g_dbus_get_file_info                 (DBusMessageIter            *iter,
