@@ -1,5 +1,3 @@
-/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
-
 /* GIO - GLib Input, Output and Streaming Library
  * 
  * Copyright (C) 2006-2007 Red Hat, Inc.
@@ -66,6 +64,10 @@ main (int argc, char *argv[])
 
   replace = FALSE;
   no_fuse = FALSE;
+
+  if (g_getenv ("GVFS_DISABLE_FUSE") != NULL)
+    no_fuse = TRUE;
+  
   error = NULL;
   if (!g_option_context_parse (context, &argc, &argv, &error))
     {
