@@ -1,4 +1,3 @@
-/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 
 /* GIO - GLib Input, Output and Streaming Library
  * 
@@ -22,7 +21,10 @@
  * Author: David Zeuthen <davidz@redhat.com>
  */
 
+#include <config.h>
+
 #include <glib.h>
+#include <glib/gi18n-lib.h>
 #include <gmodule.h>
 #include <gio/gio.h>
 
@@ -31,6 +33,9 @@
 void
 g_io_module_load (GIOModule *module)
 {
+  bindtextdomain (GETTEXT_PACKAGE, GVFS_LOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
   g_app_lookup_gconf_register (module);
 }
 
