@@ -158,7 +158,6 @@ struct _MetaTree {
   int fd;
   char *data;
   gsize len;
-  ino_t inode;
 
   guint32 tag;
   gint64 time_t_base;
@@ -470,7 +469,6 @@ meta_tree_init (MetaTree *tree)
 
   tree->fd = fd;
   tree->len = statbuf.st_size;
-  tree->inode = statbuf.st_ino;
   tree->data = data;
   tree->header = (MetaFileHeader *)data;
 
@@ -616,24 +614,12 @@ meta_tree_unref (MetaTree *tree)
 static gboolean
 meta_tree_needs_rereading (MetaTree *tree)
 {
-  struct stat statbuf;
-
   if (tree->fd == -1)
     return TRUE;
 
   if (tree->header != NULL &&
       GUINT32_FROM_BE (tree->header->rotated) == 0)
     return FALSE; /* Got a valid tree and its not rotated */
-
-  /* Sanity check to avoid infinite loops when a stable file
-     has the rotated bit set to 1 (see gnome bugzilla bug #600057) */
-
-  if (lstat (tree->filename, &statbuf) != 0)
-    return FALSE;
-
-  if (tree->inode == statbuf.st_ino)
-    return FALSE;
-
   return TRUE;
 }
 
