@@ -41,6 +41,7 @@
 #include "gproxymount.h"
 #include "gproxyvolume.h"
 #include "gproxydrive.h"
+#include "gproxymountoperation.h"
 
 G_LOCK_DEFINE_STATIC(proxy_vm);
 
@@ -72,6 +73,8 @@ static DBusHandlerResult filter_function (DBusConnection *connection, DBusMessag
 
 static void signal_emit_in_idle (gpointer object, const char *signal_name, gpointer other_object);
 
+static void dispose_in_idle (gpointer object);
+
 static gboolean is_supported (GProxyVolumeMonitorClass *klass);
 
 /* The is_supported API is kinda lame and doesn't pass in the class,
@@ -167,6 +170,33 @@ g_proxy_volume_monitor_finalize (GObject *object)
     parent_class->finalize (object);
 }
 
+static void
+g_proxy_volume_monitor_dispose (GObject *object)
+{
+  GProxyVolumeMonitor *monitor;
+  GObjectClass *parent_class;
+
+  /* since GProxyVolumeMonitor is a non-instantiatable type we're dealing with a
+   * sub-type here. So we need to look at the grandparent sub-type to get the
+   * parent class for GProxyVolumeMonitor */
+  parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (
+                                 g_type_class_peek_parent (G_OBJECT_GET_CLASS (object))));
+
+  monitor = G_PROXY_VOLUME_MONITOR (object);
+
+  /* Clear all objects to avoid circular dependencies keeping things alive.
+   * Note that atm we're keeping the union monitor alive, so this won't
+   * actually happen, but better safe than sorry in case we change this
+   * later */
+  g_hash_table_remove_all (monitor->drives);
+  g_hash_table_remove_all (monitor->volumes);
+  g_hash_table_remove_all (monitor->mounts);
+  
+ if (parent_class->dispose)
+    parent_class->dispose (object);
+}
+
+
 static GList *
 get_mounts (GVolumeMonitor *volume_monitor)
 {
@@ -490,6 +520,21 @@ signal_emit_in_idle (gpointer object, const char *signal_name, gpointer other_ob
   g_idle_add ((GSourceFunc) signal_emit_in_idle_do, data);
 }
 
+static gboolean
+dispose_in_idle_do (GObject *object)
+{
+  g_object_run_dispose (object);
+  g_object_unref (object);
+
+  return FALSE;
+}
+
+static void
+dispose_in_idle (gpointer object)
+{
+  g_idle_add ((GSourceFunc) dispose_in_idle_do, g_object_ref (object));
+}
+
 
 
 static DBusHandlerResult
@@ -595,7 +640,8 @@ filter_function (DBusConnection *connection, DBusMessage *message, void *user_da
   else  if (dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "DriveChanged") ||
             dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "DriveConnected") ||
             dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "DriveDisconnected") ||
-            dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "DriveEjectButton"))
+            dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "DriveEjectButton") ||
+            dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "DriveStopButton"))
     {
 
       dbus_message_iter_init (message, &iter);
@@ -649,14 +695,20 @@ filter_function (DBusConnection *connection, DBusMessage *message, void *user_da
               signal_emit_in_idle (monitor, "drive-eject-button", drive);
             }
         }
+      else if (strcmp (member, "DriveStopButton") == 0)
+        {
+          drive = g_hash_table_lookup (monitor->drives, id);
+          if (drive != NULL)
+            {
+              signal_emit_in_idle (drive, "stop-button", NULL);
+              signal_emit_in_idle (monitor, "drive-stop-button", drive);
+            }
+        }
 
     }
   else if (dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "VolumeChanged") ||
            dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "VolumeAdded") ||
-           dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "VolumeRemoved") ||
-           dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "MountOpAskPassword") ||
-           dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "MountOpAskQuestion") ||
-           dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "MountOpAborted"))
+           dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "VolumeRemoved"))
     {
       dbus_message_iter_init (message, &iter);
       dbus_message_iter_get_basic (&iter, &the_dbus_name);
@@ -707,27 +759,10 @@ filter_function (DBusConnection *connection, DBusMessage *message, void *user_da
               g_hash_table_remove (monitor->volumes, id);
               signal_emit_in_idle (volume, "removed", NULL);
               signal_emit_in_idle (monitor, "volume-removed", volume);
+              dispose_in_idle (volume);
               g_object_unref (volume);
             }
         }
-      else if (strcmp (member, "MountOpAskPassword") == 0)
-        {
-          volume = g_hash_table_lookup (monitor->volumes, id);
-          if (volume != NULL)
-            g_proxy_volume_handle_mount_op_ask_password (volume, &iter);
-        }
-      else if (strcmp (member, "MountOpAskQuestion") == 0)
-        {
-          volume = g_hash_table_lookup (monitor->volumes, id);
-          if (volume != NULL)
-            g_proxy_volume_handle_mount_op_ask_question (volume, &iter);
-        }
-      else if (strcmp (member, "MountOpAborted") == 0)
-        {
-          volume = g_hash_table_lookup (monitor->volumes, id);
-          if (volume != NULL)
-            g_proxy_volume_handle_mount_op_aborted (volume, &iter);
-        }
 
     }
   else if (dbus_message_is_signal (message, "org.gtk.Private.RemoteVolumeMonitor", "MountChanged") ||
@@ -788,6 +823,37 @@ filter_function (DBusConnection *connection, DBusMessage *message, void *user_da
             }
         }
     }
+  else if (dbus_message_is_method_call (message, "org.gtk.Private.RemoteVolumeMonitor", "MountOpAskPassword") ||
+           dbus_message_is_method_call (message, "org.gtk.Private.RemoteVolumeMonitor", "MountOpAskQuestion") ||
+           dbus_message_is_method_call (message, "org.gtk.Private.RemoteVolumeMonitor", "MountOpShowProcesses") ||
+           dbus_message_is_method_call (message, "org.gtk.Private.RemoteVolumeMonitor", "MountOpAborted"))
+    {
+      dbus_message_iter_init (message, &iter);
+      dbus_message_iter_get_basic (&iter, &the_dbus_name);
+      dbus_message_iter_next (&iter);
+      dbus_message_iter_get_basic (&iter, &id);
+      dbus_message_iter_next (&iter);
+
+      if (strcmp (the_dbus_name, klass->dbus_name) != 0)
+        goto not_for_us;
+
+      if (strcmp (member, "MountOpAskPassword") == 0)
+        {
+          g_proxy_mount_operation_handle_ask_password (id, &iter);
+        }
+      else if (strcmp (member, "MountOpAskQuestion") == 0)
+        {
+          g_proxy_mount_operation_handle_ask_question (id, &iter);
+        }
+      else if (strcmp (member, "MountOpShowProcesses") == 0)
+        {
+          g_proxy_mount_operation_handle_show_processes (id, &iter);
+        }
+      else if (strcmp (member, "MountOpAborted") == 0)
+        {
+          g_proxy_mount_operation_handle_aborted (id, &iter);
+        }
+    }
 
  not_for_us:
   G_UNLOCK (proxy_vm);
@@ -920,6 +986,7 @@ g_proxy_volume_monitor_class_init (GProxyVolumeMonitorClass *klass)
 
   gobject_class->constructor = g_proxy_volume_monitor_constructor;
   gobject_class->finalize = g_proxy_volume_monitor_finalize;
+  gobject_class->dispose = g_proxy_volume_monitor_dispose;
 
   monitor_class->get_mounts = get_mounts;
   monitor_class->get_volumes = get_volumes;
